@@ -9,4 +9,4 @@ class EvalEventData(BaseModel):
     model_name: str
     model_id: str
     model_type: str
-    mapping: Optional[Dict[str, str]]
+    mapping: Optional[Dict[str, Dict[str, str]]]
